/// <reference types="jest" />
import { NestingMock } from './nestingMock';
/**
 * jest Mock for curried functions
 */
export type CurryMock = NestingMock & {
    /**
     * Gets the uncurried inner jest.Mock
     * @readonly
     * @remarks contains registrations for all combinations of calls resulting in a full argument list.
     * @see global.nest.args to create partial call expectations
     */
    readonly uncurried: jest.Mock;
};
/**
 * Creates a jest mock for a curried function
 * @param {(...args: any[]) => any} mockImplementation Implementation of this mock or function to spy on
 * @param {number} [arity] total number of arguments for the curried function, provide only if it can't be derived from 'mockImplementation'
 * @returns {CurryMock} the mock
 */
export declare function fnCurried(mockImplementation: (...args: any[]) => any, arity?: number): CurryMock;
/**
 * Creates a mock for a curried function
 * @param {number} arity total number of arguments for the curried function
 * @returns {CurryMock} the mock
 */
export declare function fnCurried(arity: number): CurryMock;
